[−][src]Enum dubp_documents::documents::block::BlockDocument
Wrap a Block document.
Must be created by parsing a text document or using a builder.
Variants
V10(BlockDocumentV10)Trait Implementations
impl BlockDocumentTrait for BlockDocument[src]
fn compute_hash(&self) -> BlockHash[src]
fn compute_will_hashed_string(&self) -> String[src]
fn compute_will_signed_string(&self) -> String[src]
fn current_frame_size(&self) -> usize[src]
fn generate_compact_inner_text(&self) -> String[src]
fn generate_hash(&mut self)[src]
fn generate_inner_hash(&mut self)[src]
fn hash(&self) -> Option<BlockHash>[src]
fn increment_nonce(&mut self)[src]
fn inner_hash(&self) -> Option<Hash>[src]
fn issuers_count(&self) -> usize[src]
fn common_time(&self) -> u64[src]
fn number(&self) -> BlockNumber[src]
fn previous_blockstamp(&self) -> Blockstamp[src]
fn previous_hash(&self) -> Option<Hash>[src]
fn reduce(&mut self)[src]
fn verify_inner_hash(&self) -> Result<(), VerifyBlockHashError>[src]
fn verify_hash(&self) -> Result<(), VerifyBlockHashError>[src]
fn sign(&mut self, privkey: PrivKey)[src]
fn compute_inner_hash(&self) -> Hash[src]
Compute inner hash
impl Document for BlockDocument[src]
type PublicKey = PubKey
Type of the PublicKey used by the document.
fn version(&self) -> u16[src]
fn currency(&self) -> &str[src]
fn blockstamp(&self) -> Blockstamp[src]
fn issuers(&self) -> &Vec<Self::PublicKey>[src]
fn signatures(&self) -> &Vec<<Self::PublicKey as PublicKey>::Signature>[src]
fn as_bytes(&self) -> &[u8][src]
fn no_as_bytes(&self) -> bool[src]
Some documents do not directly store the sequence of bytes that will be signed but generate
fn to_bytes(&self) -> Vec<u8>[src]
Get document to bytes for signature verification.
fn verify_one_signature(
&self,
public_key: &Self::PublicKey,
signature: &<Self::PublicKey as PublicKey>::Signature
) -> Result<(), SigError>[src]
&self,
public_key: &Self::PublicKey,
signature: &<Self::PublicKey as PublicKey>::Signature
) -> Result<(), SigError>
Verify one signature
fn verify_signatures(&self) -> Result<(), DocumentSigsErr>[src]
Verify signatures of document content (as text format)
impl ToStringObject for BlockDocument[src]
type StringObject = BlockDocumentStringified
fn to_string_object(&self) -> Self::StringObject[src]
impl Clone for BlockDocument[src]
fn clone(&self) -> BlockDocument[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl PartialEq<BlockDocument> for BlockDocument[src]
fn eq(&self, other: &BlockDocument) -> bool[src]
fn ne(&self, other: &BlockDocument) -> bool[src]
impl Eq for BlockDocument[src]
impl Debug for BlockDocument[src]
impl<'de> Deserialize<'de> for BlockDocument[src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,
impl Serialize for BlockDocument[src]