[][src]Struct dubp_documents::documents::transaction::TransactionDocument

pub struct TransactionDocument { /* fields omitted */ }

Wrap a Transaction document.

Must be created by parsing a text document or using a builder.

Methods

impl TransactionDocument[src]

pub fn compute_hash(&mut self) -> Hash[src]

Compute transaction hash

pub fn get_hash_opt(&self) -> Option<Hash>[src]

get transaction hash option

pub fn get_hash(&mut self) -> Hash[src]

Get transaction hash

pub fn get_inputs(&self) -> &[TransactionInput][src]

Get transaction inputs

pub fn get_outputs(&self) -> &[TransactionOutput][src]

Get transaction outputs

pub fn reduce(&mut self)[src]

Lightens the transaction (for example to store it while minimizing the space required)

pub fn from_pest_pair(
    pair: Pair<Rule>
) -> Result<TransactionDocument, TextDocumentParseError>
[src]

from pest parser pair