[−][src]Enum dubp_documents::Rule
Variants
EOInlhexa_upperbase58base64no_zero_u_intu_inthashcurrencypubkeyuidblock_idblockstamped25519_sigv10idty_v10idtymembership_inmembership_outmembership_v10membershipcert_v10certrevoc_v10revoctx_locktimetx_amounttx_amount_basedu_block_idtx_indexinput_indexissuer_indexxhx_secretcsv_durationcltv_timestamptx_inputtx_input_dutx_input_txtx_unlockunlock_condunlock_sigunlock_xhxtx_outputoutput_conds_groupoutput_and_groupoutput_or_groupoutput_single_condoutput_cond_sigoutput_cond_xhxoutput_cond_csvoutput_cond_cltvtx_comment_chartx_commenttx_v10txdocument_v10documentTrait Implementations
impl TextDocumentParser<Rule> for CertificationDocumentParser[src]
type DocumentType = CertificationDocument
Type of document generated by the parser
fn parse(doc: &str) -> Result<Self::DocumentType, TextDocumentParseError>[src]
fn from_pest_pair(
cert_pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
cert_pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl TextDocumentParser<Rule> for IdentityDocumentParser[src]
type DocumentType = IdentityDocument
Type of document generated by the parser
fn parse(doc: &str) -> Result<Self::DocumentType, TextDocumentParseError>[src]
fn from_pest_pair(
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl TextDocumentParser<Rule> for MembershipDocumentParser[src]
type DocumentType = MembershipDocument
Type of document generated by the parser
fn parse(doc: &str) -> Result<Self::DocumentType, TextDocumentParseError>[src]
fn from_pest_pair(
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl TextDocumentParser<Rule> for RevocationDocumentParser[src]
type DocumentType = RevocationDocument
Type of document generated by the parser
fn parse(doc: &str) -> Result<Self::DocumentType, TextDocumentParseError>[src]
fn from_pest_pair(
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl TextDocumentParser<Rule> for TransactionDocumentParser[src]
type DocumentType = TransactionDocument
Type of document generated by the parser
fn parse(doc: &str) -> Result<Self::DocumentType, TextDocumentParseError>[src]
fn from_pest_pair(
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl TextDocumentParser<Rule> for UserDocumentDUBP[src]
type DocumentType = UserDocumentDUBP
Type of document generated by the parser
fn parse(doc: &str) -> Result<UserDocumentDUBP, TextDocumentParseError>[src]
fn from_pest_pair(
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
fn from_versioned_pest_pair(
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>[src]
version: u16,
pair: Pair<Rule>
) -> Result<Self::DocumentType, TextDocumentParseError>
impl Clone for Rule[src]
fn clone(&self) -> Rule[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl Ord for Rule[src]
fn cmp(&self, other: &Rule) -> Ordering[src]
fn max(self, other: Self) -> Self1.21.0[src]
Compares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
Compares and returns the minimum of two values. Read more
fn clamp(self, min: Self, max: Self) -> Self[src]
clamp)Restrict a value to a certain interval. Read more
impl PartialOrd<Rule> for Rule[src]
fn partial_cmp(&self, other: &Rule) -> Option<Ordering>[src]
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<Rule> for Rule[src]
fn eq(&self, other: &Rule) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl Copy for Rule[src]
impl Eq for Rule[src]
impl Debug for Rule[src]
impl Hash for Rule[src]