[−][src]Enum dubp_documents::transaction::TransactionDocument
Wrap a Transaction document.
Must be created by parsing a text document or using a builder.
Variants
Implementations
impl TransactionDocument[src]
pub fn compute_hash(&self) -> Hash[src]
Compute transaction hash
pub fn get_hash_opt(&self) -> Option<Hash>[src]
get transaction hash option
pub fn get_hash(&mut self) -> Hash[src]
Get transaction hash
pub fn reduce(&mut self)[src]
Lightens the transaction (for example to store it while minimizing the space required) WARNING: do not remove the hash as it's necessary to reverse the transaction !